@@ -13,9 +13,9 @@
 
 #include <QDate>
 #include <QDomElement>
+#include <QImage>
 #include <QString>
 #include <QUrl>
-#include <QImage>
 
 #include "author.h"
 // This include only exists for the KNS3::Entry::Status enum
@@ -52,10 +52,10 @@ public:
     typedef QList<EntryInternal> List;
 
     /**
-    * Source of the entry, A entry's data is coming from either cache, or an online provider
-    * this helps the engine know which data to use when merging cached entries with online
-    * entry data
-    */
+     * Source of the entry, A entry's data is coming from either cache, or an online provider
+     * this helps the engine know which data to use when merging cached entries with online
+     * entry data
+     */
     enum Source {
         Cache,
         Online,
@@ -72,14 +72,14 @@ public:
     };
 
     struct DownloadLinkInformation {
-        QString name;
-        QString priceAmount;
-        QString distributionType;
-        QString descriptionLink;
-        int id;
+        QString name;             // Displayed name.
+        QString priceAmount;      // Price formatted as a string.
+        QString distributionType; // OCS Distribution Type, this is for which OS the file is useful.
+        QString descriptionLink;  // Link to intermediary description.
+        int id;                   // Unique integer representing the download number in the list.
         bool isDownloadtypeLink;
-        quint64 size = 0;
-        QStringList tags;
+        quint64 size = 0;         // Size in kilobytes.
+        QStringList tags;         // variety of tags that can represent mimetype or url location.
     };
 
     enum EntryEvent {
@@ -89,6 +89,16 @@ public:
         DetailsLoadedEvent = 3,
     };
 
+    /**
+     * Represents whether the current entry is an actual catalog entry,
+     * or an entry that represents a set of entries.
+     * @since 5.83
+     */
+    enum EntryType {
+        CatalogEntry = 0, ///< These are the main entries that KNewStuff can get the details about and download links for.
+        GroupEntry        ///< these are entries whose payload is another feed. Currently only used by the OPDS provider.
+    };
+
     /**
      * Constructor.
      */
@@ -466,6 +476,13 @@ public:
     void setSource(Source source);
     Source source() const;
 
+    /**
+     * The entry type is either catalog entry, or group entry.
+     * @since 5.83
+     */
+    void setEntryType(EntryType type);
+    EntryType entryType() const;
+
     /**
      * set the xml for the entry
      * parses the xml and sets the private members accordingly
@@ -479,7 +496,7 @@ public:
      */
     bool setEntryXML(QXmlStreamReader &reader);
 
-//#if KNEWSTUFFCORE_ENABLE_DEPRECATED_SINCE(5, 36) // TODO This is still internally used and has not been fully ported
+    //#if KNEWSTUFFCORE_ENABLE_DEPRECATED_SINCE(5, 36) // TODO This is still internally used and has not been fully ported
     /**
      * set the xml for the entry
      * parses the xml and sets the private members accordingly
@@ -493,11 +510,11 @@ public:
      */
     KNEWSTUFFCORE_DEPRECATED_VERSION(5, 36, "Use EntryInternal::setEntryXML(QXmlStreamReader &)")
     bool setEntryXML(const QDomElement &xmldata);
-//#endif
+    //#endif
 
     /**
-    * get the xml string for the entry
-    */
+     * get the xml string for the entry
+     */
     QDomElement entryXML() const;
 
     /**
@@ -521,6 +538,7 @@ public:
     KNS3::Entry::Status status() const;
 
     static KNSCore::EntryInternal fromEntry(const KNS3::Entry &entry);
+
 private:
     class Private;
     QExplicitlySharedDataPointer<Private> d;
